==> jc-1.4.0.tar.gz: java/io/SerializablePermission.h <==
// public final class java.io.SerializablePermission

// class file dependencies
// @dep_class f3b2acfda592b4df java_io_SerializablePermission
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d5158e4c9a3bab21 java_security_BasicPermission
// @dep_class 2377c76e79058a72 java_security_Permission

// header file dependencies
// @dep_header java_security_BasicPermission

#include "java/security/BasicPermission.h"

#ifndef _JC_java_io_SerializablePermission_H_
#define _JC_java_io_SerializablePermission_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_io_SerializablePermission$sub_refs	_jc_java_io_SerializablePermission$sub_refs;
typedef struct _jc_java_io_SerializablePermission$sub_nonrefs	_jc_java_io_SerializablePermission$sub_nonrefs;
typedef struct _jc_java_io_SerializablePermission$refs	_jc_java_io_SerializablePermission$refs;
typedef struct _jc_java_io_SerializablePermission$nonrefs	_jc_java_io_SerializablePermission$nonrefs;
typedef struct _jc_java_io_SerializablePermission$object	_jc_java_io_SerializablePermission$object;

typedef struct _jc_java_io_SerializablePermission$fields_struct	_jc_java_io_SerializablePermission$fields_struct;
typedef const struct _jc_java_io_SerializablePermission$vmethods	_jc_java_io_SerializablePermission$vmethods;
typedef const struct _jc_java_io_SerializablePermission$vtable	_jc_java_io_SerializablePermission$vtable;
typedef const struct _jc_java_io_SerializablePermission$vtype	_jc_java_io_SerializablePermission$vtype;

// Class fields structure
struct _jc_java_io_SerializablePermission$fields_struct {
	_jc_object_array	*legal__5fnames;
	jlong	serialVersionUID;
};
extern _jc_java_io_SerializablePermission$fields_struct _jc_java_io_SerializablePermission$class_fields;

// Constructors
extern void _jc_java_io_SerializablePermission$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_io_SerializablePermission$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_io_SerializablePermission$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_io_SerializablePermission$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Static methods
extern void _jc_java_io_SerializablePermission$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_io_SerializablePermission$vmethods {
};

// Vtable
struct _jc_java_io_SerializablePermission$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Permission$vmethods	java_security_Permission;
	_jc_java_security_BasicPermission$vmethods	java_security_BasicPermission;
	_jc_java_io_SerializablePermission$vmethods	java_io_SerializablePermission;
};

// Vtype
struct _jc_java_io_SerializablePermission$vtype {
	_jc_type			type;
	_jc_java_io_SerializablePermission$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_SerializablePermission$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_io_SerializablePermission$refs {
    _jc_java_io_SerializablePermission$sub_refs	java_io_SerializablePermission;
    _jc_java_security_BasicPermission$sub_refs	java_security_BasicPermission;
    _jc_java_security_Permission$sub_refs	java_security_Permission;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_SerializablePermission$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_SerializablePermission$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Permission$sub_nonrefs	java_security_Permission;
    _jc_java_security_BasicPermission$sub_nonrefs	java_security_BasicPermission;
    _jc_java_io_SerializablePermission$sub_nonrefs	java_io_SerializablePermission;
};

// Object instance structure
struct _jc_java_io_SerializablePermission$object {
	_jc_java_io_SerializablePermission$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_SerializablePermission$vtype	*vtype;
	_jc_java_io_SerializablePermission$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_SerializablePermission$vtype _jc_java_io_SerializablePermission$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_SerializablePermission, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_SerializablePermission$class_object;

#endif	/* _JC_java_io_SerializablePermission_H_ */

==> jc-1.4.6.tar.gz: java/io/SerializablePermission.h <==
// public final class java.io.SerializablePermission

// class file dependencies
// @dep_class f3b2acfda592b4df java_io_SerializablePermission
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d5158e4c9a3bab21 java_security_BasicPermission
// @dep_class 2377c76e79058a72 java_security_Permission

// header file dependencies
// @dep_header java_security_BasicPermission

#include "java/security/BasicPermission.h"

#ifndef _JC_java_io_SerializablePermission_H_
#define _JC_java_io_SerializablePermission_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_io_SerializablePermission$sub_refs	_jc_java_io_SerializablePermission$sub_refs;
typedef struct _jc_java_io_SerializablePermission$sub_nonrefs	_jc_java_io_SerializablePermission$sub_nonrefs;
typedef struct _jc_java_io_SerializablePermission$refs	_jc_java_io_SerializablePermission$refs;
typedef struct _jc_java_io_SerializablePermission$nonrefs	_jc_java_io_SerializablePermission$nonrefs;
typedef struct _jc_java_io_SerializablePermission$object	_jc_java_io_SerializablePermission$object;

typedef struct _jc_java_io_SerializablePermission$fields_struct	_jc_java_io_SerializablePermission$fields_struct;
typedef const struct _jc_java_io_SerializablePermission$vmethods	_jc_java_io_SerializablePermission$vmethods;
typedef const struct _jc_java_io_SerializablePermission$vtable	_jc_java_io_SerializablePermission$vtable;
typedef const struct _jc_java_io_SerializablePermission$vtype	_jc_java_io_SerializablePermission$vtype;

// Class fields structure
struct _jc_java_io_SerializablePermission$fields_struct {
	_jc_object_array	*legal__5fnames;
	jlong	serialVersionUID;
};
extern _jc_java_io_SerializablePermission$fields_struct _jc_java_io_SerializablePermission$class_fields;

// Constructors
extern void _jc_java_io_SerializablePermission$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_io_SerializablePermission$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_SerializablePermission$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_io_SerializablePermission$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java_io_SerializablePermission$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_io_SerializablePermission$vmethods {
};

// Vtable
struct _jc_java_io_SerializablePermission$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Permission$vmethods	java_security_Permission;
	_jc_java_security_BasicPermission$vmethods	java_security_BasicPermission;
	_jc_java_io_SerializablePermission$vmethods	java_io_SerializablePermission;
};

// Vtype
struct _jc_java_io_SerializablePermission$vtype {
	_jc_type			type;
	_jc_java_io_SerializablePermission$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_SerializablePermission$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_io_SerializablePermission$refs {
    _jc_java_io_SerializablePermission$sub_refs	java_io_SerializablePermission;
    _jc_java_security_BasicPermission$sub_refs	java_security_BasicPermission;
    _jc_java_security_Permission$sub_refs	java_security_Permission;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_SerializablePermission$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_SerializablePermission$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Permission$sub_nonrefs	java_security_Permission;
    _jc_java_security_BasicPermission$sub_nonrefs	java_security_BasicPermission;
    _jc_java_io_SerializablePermission$sub_nonrefs	java_io_SerializablePermission;
};

// Object instance structure
struct _jc_java_io_SerializablePermission$object {
	_jc_java_io_SerializablePermission$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_SerializablePermission$vtype	*vtype;
	_jc_java_io_SerializablePermission$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_SerializablePermission$vtype _jc_java_io_SerializablePermission$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_SerializablePermission, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_SerializablePermission$class_object;

#endif	/* _JC_java_io_SerializablePermission_H_ */
